Improve this Doc

# Error: $sce:insecurl
Processing of a Resource from Untrusted Source Blocked

    Blocked loading resource from url not allowed by $sceDelegate policy.  URL: {0}

## Description

AngularJS' Strict Contextual Escaping (SCE) mode (enabled by default) has blocked loading a resource from an insecure URL.

Typically, this would occur if you're attempting to load an Angular template from an untrusted source. It's also possible that a custom directive threw this error for a similar reason.

Angular only loads templates from trusted URLs (by calling $sce.getTrustedResourceUrl on the template URL).

By default, only URLs that belong to the same origin are trusted. These are urls with the same domain, protocol and port as the application document.

The ngInclude directive and directives that specify a `templateUrl` require a trusted resource URL.

To load templates from other domains and/or protocols, either adjust the whitelist/ blacklist or wrap the URL with a call to $sce.trustAsResourceUrl.

Note: The browser's Same Origin Policy and Cross-Origin Resource Sharing (CORS) policy apply that may further restrict whether the template is successfully loaded. (e.g. neither cross-domain requests won't work on all browsers nor `file://` requests on some browsers)